@@ -31,3 +31,18 @@ test_that("oadoi_fetch returns", {
   # missing email address
   expect_error(oadoi_fetch("10.1038/ng.3260"))
 })
+
+test_that("emails are validated", {
+  skip_on_cran()
+  expect_error(oadoi_fetch("10.1038/ng.3260", email = 123))
+  expect_error(oadoi_fetch("10.1038/ng.3260", email = "najko@gnx"))
+  expect_error(oadoi_fetch("10.1038/ng.3260", email = "FOOL"))
+})
+
+## lintr
+if (requireNamespace("lintr", quietly = TRUE)) {
+  context("lints")
+  test_that("Package Style", {
+    lintr::expect_lint_free()
+  })
+}
